==> jc-1.4.0.tar.gz: javax/print/attribute/standard/MediaPrintableArea.h <==
// public final class javax.print.attribute.standard.MediaPrintableArea

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1d5f93836f76c6a4 javax_print_attribute_standard_MediaPrintableArea

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_standard_MediaPrintableArea_H_
#define _JC_javax_print_attribute_standard_MediaPrintableArea_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs	_jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs	_jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$refs	_jc_javax_print_attribute_standard_MediaPrintableArea$refs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs	_jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$object	_jc_javax_print_attribute_standard_MediaPrintableArea$object;

typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct	_jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_MediaPrintableArea$vmethods	_jc_javax_print_attribute_standard_MediaPrintableArea$vmethods;
typedef const struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtable	_jc_javax_print_attribute_standard_MediaPrintableArea$vtable;
typedef const struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtype	_jc_javax_print_attribute_standard_MediaPrintableArea$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24MediaPrintableArea;
	jlong	serialVersionUID;
	jint	INCH;
	jint	MM;
};
extern _jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct _jc_javax_print_attribute_standard_MediaPrintableArea$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_MediaPrintableArea$method$_init$852698ecec68d93d(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jfloat, jfloat, jfloat, jfloat, jint);
extern void _jc_javax_print_attribute_standard_MediaPrintableArea$method$_init$98f1a2a446c839a1(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint, jint, jint, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaPrintableArea$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *);
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getHeight$03e79e9f6c043181(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_MediaPrintableArea$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *);
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getWidth$dc5dd3014fa5e097(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getX$66c2004aa10f3957(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getY$0bd1f9b32c922e39(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getHeight$03e79e9f6c043181;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getWidth$dc5dd3014fa5e097;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getX$66c2004aa10f3957;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getY$0bd1f9b32c922e39;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaPrintableArea$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_MediaPrintableArea$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *);
	jfloat	(*getHeight$03e79e9f6c043181)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *);
	jfloat	(*getWidth$dc5dd3014fa5e097)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
	jfloat	(*getX$66c2004aa10f3957)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
	jfloat	(*getY$0bd1f9b32c922e39)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint);
};

// Vtable
struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_standard_MediaPrintableArea$vmethods	javax_print_attribute_standard_MediaPrintableArea;
};

// Vtype
struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_MediaPrintableArea$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$refs {
    _jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs	javax_print_attribute_standard_MediaPrintableArea;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs {
	jfloat	x;
	jfloat	y;
	jfloat	width;
	jfloat	height;
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs	javax_print_attribute_standard_MediaPrintableArea;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_MediaPrintableArea$object {
	_jc_javax_print_attribute_standard_MediaPrintableArea$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_MediaPrintableArea$vtype	*vtype;
	_jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_MediaPrintableArea$vtype _jc_javax_print_attribute_standard_MediaPrintableArea$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_MediaPrintableArea, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_MediaPrintableArea$class_object;

#endif	/* _JC_javax_print_attribute_standard_MediaPrintableArea_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/MediaPrintableArea.h <==
// public final class javax.print.attribute.standard.MediaPrintableArea

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1d5f93836f76c6a4 javax_print_attribute_standard_MediaPrintableArea

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_standard_MediaPrintableArea_H_
#define _JC_javax_print_attribute_standard_MediaPrintableArea_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs	_jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs	_jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$refs	_jc_javax_print_attribute_standard_MediaPrintableArea$refs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs	_jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$object	_jc_javax_print_attribute_standard_MediaPrintableArea$object;

typedef struct _jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct	_jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_MediaPrintableArea$vmethods	_jc_javax_print_attribute_standard_MediaPrintableArea$vmethods;
typedef const struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtable	_jc_javax_print_attribute_standard_MediaPrintableArea$vtable;
typedef const struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtype	_jc_javax_print_attribute_standard_MediaPrintableArea$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24MediaPrintableArea;
	jlong	serialVersionUID;
	jint	INCH;
	jint	MM;
};
extern _jc_javax_print_attribute_standard_MediaPrintableArea$fields_struct _jc_javax_print_attribute_standard_MediaPrintableArea$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_MediaPrintableArea$method$_init$852698ecec68d93d(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jfloat, jfloat, jfloat, jfloat, jint) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_standard_MediaPrintableArea$method$_init$98f1a2a446c839a1(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaPrintableArea$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *) _JC_JCNI_ATTR;
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getHeight$03e79e9f6c043181(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_MediaPrintableArea$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *) _JC_JCNI_ATTR;
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getWidth$dc5dd3014fa5e097(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getX$66c2004aa10f3957(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
extern jfloat _jc_javax_print_attribute_standard_MediaPrintableArea$method$getY$0bd1f9b32c922e39(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getHeight$03e79e9f6c043181;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getWidth$dc5dd3014fa5e097;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getX$66c2004aa10f3957;
extern _jc_method _jc_javax_print_attribute_standard_MediaPrintableArea$method_info$getY$0bd1f9b32c922e39;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaPrintableArea$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_MediaPrintableArea$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *) _JC_JCNI_ATTR;
	jfloat	(*getHeight$03e79e9f6c043181)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *) _JC_JCNI_ATTR;
	jfloat	(*getWidth$dc5dd3014fa5e097)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
	jfloat	(*getX$66c2004aa10f3957)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
	jfloat	(*getY$0bd1f9b32c922e39)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaPrintableArea$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_standard_MediaPrintableArea$vmethods	javax_print_attribute_standard_MediaPrintableArea;
};

// Vtype
struct _jc_javax_print_attribute_standard_MediaPrintableArea$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_MediaPrintableArea$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$refs {
    _jc_javax_print_attribute_standard_MediaPrintableArea$sub_refs	javax_print_attribute_standard_MediaPrintableArea;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs {
	jfloat	x;
	jfloat	y;
	jfloat	width;
	jfloat	height;
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_standard_MediaPrintableArea$sub_nonrefs	javax_print_attribute_standard_MediaPrintableArea;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_MediaPrintableArea$object {
	_jc_javax_print_attribute_standard_MediaPrintableArea$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_MediaPrintableArea$vtype	*vtype;
	_jc_javax_print_attribute_standard_MediaPrintableArea$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_MediaPrintableArea$vtype _jc_javax_print_attribute_standard_MediaPrintableArea$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_MediaPrintableArea, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_MediaPrintableArea$class_object;

#endif	/* _JC_javax_print_attribute_standard_MediaPrintableArea_H_ */
